<?php

/* Helpers
========================================================================== */
// include_once get_theme_file_path('app/helpers/...')

/* App
========================================================================== */
include_once get_theme_file_path('app/config.php');
include_once get_theme_file_path('app/scripts/post-types.php');

/* Actions & Filters
========================================================================== */
add_action('show_admin_bar', '__return_false');
add_filter('widget_text', 'do_shortcode');
add_filter('retrieve_password_message', "change_template_password_recovery", 10, 4 );
// add_filter( 'show_admin_bar', fn() => ! current_user_can( 'manage_options' ) && !is_admin() ? false : true );
remove_action('wp_head', 'wp_generator');
// adicona jQuery ao tema
add_action('wp_enqueue_scripts', fn() => wp_enqueue_script('jquery'));

/* Theme functions
========================================================================== */

// Define a página 'Home' como a página inicial
add_action('after_switch_theme', function() {
    if ('1' !== get_option('my_theme_activated')) {
		update_option('page_on_front', get_page_by_title('Home')->ID ?? wp_insert_post([
			'post_title'    => 'Home',
			'post_content'  => '',
			'post_status'   => 'publish',
			'post_type'     => 'page'
		]));
		update_option('show_on_front', 'page');
    }
});


function wp_mail_return_texthtml(){
    return 'text/html';
}
add_filter('wp_mail_content_type', 'wp_mail_return_texthtml');


function get_image_url($file = ''){
    return get_template_directory_uri().'/assets/images/'.$file;
}


function image_url($file = ''){
    echo get_image_url($file);
}

add_filter('upload_mimes', function($mimes){
    $mimes['svg'] = 'image/svg+xml';
    return $mimes;
});


add_action('acf/init', function() {
    if(function_exists('acf_add_options_page')){
        $option_page = acf_add_options_page(array(
            'page_title'    => __('Opções do Tema'),
            'menu_title'    => __('Opções do Tema'),
            'menu_slug'     => 'opcoes-do-tema',
            'parent_slug'   => 'options-general.php',
            'capability'    => 'edit_posts',
            'redirect'      => false
        ));
    }
});

/**
 * Change Template recovery password.
 */
function change_template_password_recovery( $message, $key, $user_login, $user_data ){
    $message = file_get_contents(get_template_directory().'/app/tamplate-recovery-password.html');
    $message = str_replace("[logo]", '<a href="'.get_site_url().'" title="'.get_bloginfo('name').' - '.get_bloginfo('description').'" ><img src="'.get_image_url('logo.webp').'" alt="'.get_bloginfo('name').'"></a>', $message);
    $message = str_replace("[nome]", $user_login, $message);
    $message = str_replace("[site-url]", get_site_url(), $message);
    $message = str_replace("[password-reset-link]", network_site_url("wp-login.php?action=rp&key=$key&login=".rawurlencode($user_login), 'login'), $message);

    return $message;
}

/**
 * Print the image of the logo, if it is the home place a wrap of h1.
 */
function the_logo($img = 'logo.webp'){
	$blog_name = get_bloginfo('name');
	$image_path = get_template_directory().'/assets/images/'.$img;
	$image_type = pathinfo($image_path, PATHINFO_EXTENSION);
	$image_size = getimagesize($image_path);

	if ($image_type === 'svg'): ?>
		<a href="<?= home_url('/') ?>" title="<?= $blog_name.' - '.get_bloginfo('description') ?>" class="logo">
			<?= file_get_contents($image_path) ?>
		</a>
	<?php else: ?>
		<a href="<?= home_url('/') ?>" title="<?= $blog_name.' - '.get_bloginfo('description') ?>" class="logo">
			<img src="<?= get_image_url($img) ?>" alt="<?= $blog_name ?>" width="<?= $image_size[0] ?>" height="<?= $image_size[1] ?>">
		</a>
	<?php endif;
}


function the_image($image_id = null, $size = "full"){
	if($image_url = wp_get_attachment_image_src($image_id, $size)[0]){
		$image_alt = get_post_meta($image_id, '_wp_attachment_image_alt', TRUE);
		$image_metadata = ($size != "full") ? wp_get_attachment_metadata($image_id)["sizes"][$size] : wp_get_attachment_metadata($image_id);
		return '<img src="' . $image_url . '" alt="' . $image_alt . '" width="' . $image_metadata['width'] . '" height="' . $image_metadata['height'] . '" />';
	}else{
		return "";
	}
}

/**
 * Change the login form logo.
 */
function change_login_form_logo(){
    echo '<style>.login h1 a{background-image:url('.get_image_url('logo-login-form.png').')!important;}</style>';
}
add_action('login_enqueue_scripts', 'change_login_form_logo');

/**
 * Change the login form logo url.
 */
function login_form_logo_url(){
    return get_home_url();
}
add_filter('login_headerurl', 'login_form_logo_url');

/**
 * Standardizes login error message, so as not to show when the user exists.
 */
function wrong_login(){
    return '<b>ERRO</b>: Usuário ou senha incorretos.';
}
add_filter('login_errors', 'wrong_login');

/**
 * Change title of the login form logo.
 */
function login_form_logo_url_title(){
    return get_bloginfo('name').' - Desenvolvido por Área Local';
}
add_filter('login_headertext', 'login_form_logo_url_title');

/**
 * Adds main navigation, html5 support and post thumbnail.
 */
function al_setup(){
    register_nav_menus(['principal' => 'Navegação Principal']);
    add_theme_support('post-thumbnails');
    add_theme_support('html5', ['comment-list', 'comment-form', 'search-form', 'gallery', 'caption']);
}
add_action('after_setup_theme', 'al_setup');

/**
 * Add home in the menu.
 */
function show_home_menu($args){
    $args['show_home'] = true;

    return $args;
}
add_filter('wp_page_menu_args', 'show_home_menu');

/**
 * Records widget areas.
 */
function add_widget_areas(){
    register_sidebar([
        'name' => 'Área de Widget Primária',
        'id' => 'area-widget-primaria',
        'description' => 'Área de Widget Primária',
        'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ]);

    register_sidebar([
        'name' => 'Área de Widget Secundária',
        'id' => 'area-widget-secundaria',
        'description' => 'Área de Widget Secundária',
        'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ]);
}
add_action('widgets_init', 'add_widget_areas');

/**
 * Disables wordpress emojis.
 */
function disable_wp_emojicons(){
    remove_action('admin_print_styles', 'print_emoji_styles');
    remove_action('wp_head', 'print_emoji_detection_script', 7);
    remove_action('admin_print_scripts', 'print_emoji_detection_script');
    remove_action('wp_print_styles', 'print_emoji_styles');
    remove_filter('wp_mail', 'wp_staticize_emoji_for_email');
    remove_filter('the_content_feed', 'wp_staticize_emoji');
    remove_filter('comment_text_rss', 'wp_staticize_emoji');
}
add_action('init', 'disable_wp_emojicons');

function sanitize_filename($filename){
    $ext = explode('.', $filename);
    $ext = end($ext);
    $sanitized = preg_replace('/[^a-zA-Z0-9-_.]/', '', substr($filename, 0, -(strlen($ext) + 1)));
    $sanitized = str_replace('.', '-', $sanitized);

    if (function_exists('sanitize_title')) {
        $sanitized = sanitize_title($sanitized);
    }

    return strtolower($sanitized.'.'.$ext);
}
add_filter('sanitize_file_name', 'sanitize_filename', 10);


function custom_short_excerpt($excerpt, $length = 200){
    $text = substr($excerpt, 0, $length);

    if (strlen($excerpt) > $length) {
        $text .= ' ...';
    }

    return $text;
}
add_filter('the_excerpt', 'custom_short_excerpt');

/**
 * Change excerpt tag.
 */
function change_excerpt_more(){
    return '<a title="'.get_the_title().'" href="'.get_permalink().'" class="more-link">Ler mais</a>';
}
add_filter('excerpt_more', 'change_excerpt_more');

/**
 * Add admin.js and admin.css script to the admin screen.
 */
function adminScriptsStyles(){
    wp_enqueue_style('admin-styles', get_bloginfo('template_url').'/assets/css/'.(in_array("sub-administrador", wp_get_current_user()->roles) ? 'sub-administrador.css' : 'admin.css'));
    wp_enqueue_script('admin-functions', get_bloginfo('template_url').'/assets/js/admin.js');
}
add_action('admin_enqueue_scripts', 'adminScriptsStyles');

/**
 * Render Área Local help panel.
 */
function custom_dashboard_help(){
    echo '
		<p>
			Bem-vindo ao tema Área Local! precisa de ajuda?</br> Contate o suporte
			<a target="_blank" href="https://suporte-arealocal.tomticket.com/">aqui!</a>
		</p>
		<h2>Contato</h2>
		<p>Telefone/Whastapp: <a target="_blank" href="https://wa.me/554735219850"><b>(47) 3521-9850</b></a></p>
		<p>E-mail:
			<a target="_blank" href="mailto:contato@arealocal.com.br"><b>contato@arealocal.com.br</b></a>
		</p>
	';
}

/**
 * Enables service area on the Wordpress dashboard.
 */
function my_custom_dashboard_widgets(){
    wp_add_dashboard_widget('atendimento-arealocal', 'Atendimento Área Local', 'custom_dashboard_help');
}
// add_action('wp_dashboard_setup', 'my_custom_dashboard_widgets');


function get_thumbnail_url($post_id, $size){
    if (!isset($post_id)) {
        $post_id = get_the_ID();
    }
    if (has_post_thumbnail($post_id)) {
        $post_thumbnail_url = get_the_post_thumbnail_url('', $size);
    } else {
        $post_thumbnail_url = get_image_url('default.webp');
    }

    return $post_thumbnail_url;
}

/**
 * Render pagination links.
 */
function paginationLinks($query, $url = ''){
    $big = 999999999;
    $url = empty($url) ? str_replace($big, '%#%', esc_url(get_pagenum_link($big))) : $url.'page/%#%/';

    if ($query->max_num_pages > 1) {
        $current_page = max(1, get_query_var('paged'));

        echo paginate_links([
            'base' => $url,
            'show_all' => false,
            'format' => '?paged=%#%',
            'current' => $current_page,
            'total' => $query->max_num_pages,
            'prev_text' => '<i class="fa-solid fa-chevron-left"></i>',
            'next_text' => '<i class="fa-solid fa-chevron-right"></i>',
        ]);
    }
}

/**
 * Adequate pagination for single-post and archive-post.
 */
function custom_posts_per_page($query)
{
    global $pagenow;

    if ($query->is_archive('post') && 'edit.php' !== $pagenow) {
        set_query_var('posts_per_page', 1);
    }
}
add_action('pre_get_posts', 'custom_posts_per_page');

/**
 * Change some archive page title.
 */
function customArchiveTitles($title)
{
    if (is_post_type_archive('some_archive')) {
        return 'Some Archive';
    }

    return $title;
}
add_filter('wp_title', 'customArchiveTitles');
add_filter('get_the_archive_title', 'customArchiveTitles');

/**
 * Custom actions before template rendering.
 */
function preTemplateAction($template)
{
    return $template;
}
add_filter('template_include', 'preTemplateAction');

// Change admin panel color scheme
wp_admin_css_color(
    'area-structure-4',
    __('Área Structure 4'),
    get_bloginfo('template_url').'/assets/css/al-admin-color-scheme.min.css',
    [
        '#222',
        '#e0e047',
        '#00244c',
        '#19539a',
    ],
    [
        'base' => '#e5f8ff',
        'focus' => '#fff',
        'current' => '#fff',
    ]
);

/**
 * Set "area-structure-4" as default color scheme.
 */
function setDefaultAdminColor($userId)
{
    wp_update_user([
        'ID' => $userId,
        'admin_color' => 'area-structure-4',
    ]);
}
add_action('user_register', 'setDefaultAdminColor');

/**
 * Redirecionamento costumizado, conforme categoria ou tax
 */
function template_redirect($template) {
    if(is_tax('tax-name')) {
        $template = get_query_template('page-name');
    }

    if(is_home()) {
        $template = get_query_template('page-name');
    }

    if(is_archive('post-type')) {
        $template = get_query_template('page-name');
    }

   return $template;
}
//add_filter('template_include', 'template_redirect');

//desabilita comentários
function remove_comments() {
    remove_menu_page('edit-comments.php');
}
add_action('admin_menu', 'remove_comments');

/* WP REST
========================================================================== */
include_once get_theme_file_path('app/routes.php');


// Gera iframe do youtube
function generateYouTubeEmbed($url) {
    if (preg_match('/^(?:https?:\/\/)?(?:www\.)?(?:youtube\.com\/watch\?v=|youtu\.be\/)([a-zA-Z0-9_-]{11})/', $url, $match)) {
        $videoId = $match[1];

        $iframe = '<iframe width="100%" height="315" src="https://www.youtube.com/embed/' . $videoId . '" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';

        return $iframe;
    } else {
        return 'URL inválida do YouTube.';
    }
}


// Importa lista de touros no post de leilões
add_action('save_post', function ($post_id, $post, $update) {
    if ($post->post_type == 'leiloes') {
		if ($file = get_field('touros_lista', $post_id)) {

			if($lista = get_post_meta($post_id, 'touros', true)){
				for ($i = 0; $i < intval($lista); $i++) {
					foreach (array('lote', 'rng', 'meses', 'pai', 'avo_materno', 'peso', 'ce', 'top_mgte', 'pmgz_deca', 'desmama_pd-ed', 'sobreano_ps-ed', 'maternal_pm-em', 'longevidade_stay', 'fertilidade_pe-365', 'video') as $subfield) {
						delete_post_meta($post_id, "touros_{$i}_{$subfield}");
					}
				}
				update_post_meta($post_id, 'touros', 0);
			}

            if (($handle = fopen($file, "r")) !== FALSE) {
                $header = fgetcsv($handle, 1000, ",");
                if (count($header) > 1) {
                    $separator = ",";
                } else {
                    $separator = ";";
                }
                while (($data = fgetcsv($handle, 1000, $separator)) !== FALSE) {
                    add_row('touros', [
                        'lote'               => $data[0],
                        'rng'                => $data[1],
                        'meses'              => $data[2],
                        'pai'                => $data[3],
                        'avo_materno'        => $data[4],
                        'peso'               => $data[5],
                        'ce'                 => $data[6],
                        'top_mgte'           => $data[7],
                        'pmgz_deca'          => $data[8],
                        'desmama_pd-ed'      => $data[9],
                        'sobreano_ps-ed'     => $data[10],
                        'maternal_pm-em'     => $data[11],
                        'longevidade_stay'   => $data[12],
                        'fertilidade_pe-365' => $data[13],
                        'video'              => $data[14]
                    ], $post_id);
                }
                fclose($handle);
            }
		}
    }
}, 10, 3);


add_filter('manage_posts_columns', function($defaults) {
    if (get_current_screen()->post_type === 'post') {
        $date_column = $defaults['date'];
        unset($defaults['date']);
        $defaults['likes_dislikes'] = 'Likes/Dislikes';
        $defaults['date'] = $date_column;
    }
    return $defaults;
});

add_action('manage_posts_custom_column', function($column_name, $post_id) {
    if ($column_name === 'likes_dislikes') {
        echo '&#128077; '.(($like_count = get_post_meta($post_id, 'pld_like_count', true)) ? $like_count : "0");
        echo ' |&#128078; '.(($dislike_count = get_post_meta($post_id, 'pld_dislike_count', true)) ? $dislike_count : "0");
    }
}, 10, 2);


// Adiciona ID na listegem de objeto de post do ACF
add_filter('acf/fields/post_object/result', function ($title, $post, $field, $post_id) {
    if (empty($post) || !is_a($post, 'WP_Post')) {
        return $title;
    }
    $post_id = $post->ID;
    $post_title = get_the_title($post_id);
    $title_with_id = "ID($post_id) - $post_title";

    return $title_with_id;
}, 10, 4);

function custom_add_id_column($columns) {
    $columns = array_merge(
        array('cb' => '<input type="checkbox" />', 'id' => 'ID'),
        $columns
    );
    return $columns;
}

function custom_id_column_content($column, $post_id) {
    if ($column === 'id') {
        echo $post_id;
    }
}

add_filter('manage_post_posts_columns', 'custom_add_id_column');
add_action('manage_post_posts_custom_column', 'custom_id_column_content', 10, 2);

add_filter('manage_leiloes_posts_columns', 'custom_add_id_column');
add_action('manage_leiloes_posts_custom_column', 'custom_id_column_content', 10, 2);

add_filter('manage_racadores_posts_columns', 'custom_add_id_column');
add_action('manage_racadores_posts_custom_column', 'custom_id_column_content', 10, 2);

add_filter('manage_fotos-e-videos_posts_columns', 'custom_add_id_column');
add_action('manage_fotos-e-videos_posts_custom_column', 'custom_id_column_content', 10, 2);

add_filter('manage_page_posts_columns', 'custom_add_id_column');
add_action('manage_page_posts_custom_column', 'custom_id_column_content', 10, 2);


// Ajusta busca da listagem de posts para buscar também por ID
add_filter('pre_get_posts', function($query) {
    global $pagenow, $post_type;
    if (is_admin() && $pagenow == 'edit.php') {
        $search_term = isset($_GET['s']) ? $_GET['s'] : '';
        if (is_numeric($search_term)) {
            $query->set('post__in', array(intval($search_term)));
            $query->set('s', '');
        }
    }
});


add_filter('nav_menu_css_class', function($classes, $item) {
    if (is_singular('post')) {
        $archive_link = get_permalink( get_page_by_path("news"));
        if (strpos($item->url, $archive_link) !== false) {
            $classes[] = 'current-menu-item';
        }
    }elseif (is_singular('leiloes')) {
        $archive_link = get_post_type_archive_link('leiloes');
        if (strpos($item->url, $archive_link) !== false) {
            $classes[] = 'current-menu-item';
        }
    }elseif (is_singular('racadores')) {
        $archive_link = get_post_type_archive_link('racadores');
        if (strpos($item->url, $archive_link) !== false) {
            $classes[] = 'current-menu-item';
        }
    }elseif (is_singular('fotos-e-videos')) {
        $archive_link = get_post_type_archive_link('fotos-e-videos');
        if (strpos($item->url, $archive_link) !== false) {
            $classes[] = 'current-menu-item';
        }
    }
    return $classes;
}, 10, 2);

// Permitir acesso à guia "Newsletter" para editores
function permitir_acesso_editor_ao_plugin_newsletter() {
    $editor_role = get_role('editor');
    if ($editor_role) {
        $editor_role->add_cap('newsletter_access'); // 'newsletter_access' é uma capacidade fictícia
    }
}
add_action('init', 'permitir_acesso_editor_ao_plugin_newsletter');


function get_seo_yoast() {
    if (!is_plugin_active('wordpress-seo/wp-seo.php')) {
        return;
    }
    $url_relativa = '';
    if (is_singular()) {
        $object_id = get_queried_object_id();
        $url_relativa = get_permalink($object_id);
    } elseif (is_category() || is_tag() || is_tax()) {
        $term = get_queried_object();
        $url_relativa = get_term_link($term);
    } elseif (is_front_page()) {
        $url_relativa = home_url();
    }
    if (empty($url_relativa)) {
        return;
    }
    $response = wp_remote_get(home_url() . '/wp-json/yoast/v1/get_head?url=' . urlencode($url_relativa));
    if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);
        if (!empty($data['html'])) {
            echo $data['html'];
        }
    }
}
